Build application theme configuration YAML file
Source:R/themeConfigurationsAddin.R
themeConfigurationsAddin.RdCall this as an addin to build valid yaml file that is needed for creating application periscope_style.yaml file. The generated file can be used in periscope2 app by putting it inside generated app www folder.
Examples
if (interactive()) {
periscope2:::themeConfigurationsAddin()
}