Display app log data in downloadableReactTable table containing logged user actions. Table contents are auto updated
whenever a user action is logged. User can search for logs, sort them by time and download them in CSV or TSV format.
The id must match the same id configured in server.R file upon calling fw_server_setup method
Usage
logViewerOutput(id = "logViewer")
Value
downloadableReactTableUI instance
Arguments
id
character id for the object(default = "logViewer")
Table columns
action - the action that id logged in any place in app
time - action time
Example
logViewerOutput('logViewer')
Shiny Usage
Add the log viewer box to your box list
It is paired with a call to fw_server_setup method in server.R file